/*
 * config.cpp
 * Copyright (C) Aitor Cuadrado Zubizarreta <aitor_czr@gnuinos.org>
 * 
 * wmlogout is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * wmlogout is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * See the COPYING file. * 
 */


#include <iostream>

#include "config.h"
#include "svr.h"


Config::Config(int argc, char **argv)
{
	for(int i=0; i<argc; i++)
		argvs.push_back(std::string(argv[i]));

	get_pid();
	FILE_DESCRIPTOR = "/tmp/wmlogout_" + PID + ".socket";

	get_current_path();
	set_bin_path();
	get_pixmaps();
}

Config::~Config()
{
	Glib::RefPtr<Gio::File> ref_path = Gio::File::create_for_path(FILE_DESCRIPTOR.c_str());
	if(ref_path->query_exists()) {	
		try {
			std::remove(FILE_DESCRIPTOR.c_str());
		}
		catch( const std::exception& e ) {
			throw std::runtime_error("Error deleting Config file descriptor.\n");
		}
	};
}

void Config::get_pid()
{
	pid_t pid = getpid();	
	std::string str;
	
	char *mypid = NULL;
	if (asprintf(&mypid, "%jd", (intmax_t) pid) != -1) {
		str = std::string(mypid);
		free(mypid); // cleanup when done.
	}
	
	PID = str;
}

void Config::get_current_path()
{
	char current_working_dir[1024] = {0}; 
	getcwd(current_working_dir, 1024);	
	CURRENT_PATH = std::string(current_working_dir);
	std::cout << "Current path is " << CURRENT_PATH << std::endl;
}

void Config::set_bin_path()
{
	Glib::RefPtr<Gio::File> ref_path_A = Gio::File::create_for_path( (CURRENT_PATH + "/wmlsuid").c_str() );		
	Glib::RefPtr<Gio::File> ref_path_B = Gio::File::create_for_path( "/lib/wmlogout/bin/wmlsuid" );
	
	std::string path;
  
	if ( ref_path_A->query_exists() )
		path = CURRENT_PATH + "/";

	else if ( ref_path_B->query_exists() )
		path = "/lib/wmlogout/bin/";
  
	else std::cerr << " The wmlsuid executable doesn't exist! " << std::endl;
	
	CLIENT = path + "wmlsuid &";
}

void Config::get_pixmaps()
{
	Glib::RefPtr<Gio::File> ref_path_A = Gio::File::create_for_path((CURRENT_PATH + "/images/openbox.png").c_str());
	Glib::RefPtr<Gio::File> ref_path_B = Gio::File::create_for_path("/usr/share/wmlogout/images/openbox.png");

	std::string path;
	
	if ( ref_path_A->query_exists() )
		path = CURRENT_PATH + "/images/";

	else if ( ref_path_B->query_exists() )
		path = "/usr/share/wmlogout/images/";
  
	else std::cerr << " Image's path doesn't exist! " << std::endl;
	
	LOGO = path + "openbox.png";
	SHUTDOWN_ICON = path + "shutdown.png";
	CANCEL_ICON = path + "cancel.png";
	REBOOT_ICON = path + "reboot.png";
	LOGOUT_ICON = path + "logout.png";
}
